---

title: StaggeredFadeAndSlide

---

# StaggeredFadeAndSlide

Renders a transition group wrapping the elements passed in the default slot and animating
them with a staggered fade and slide animation.

## Props

| Name                 | Description                                                                    | Type                 | Default            |
| -------------------- | ------------------------------------------------------------------------------ | -------------------- | ------------------ |
| <code>appear</code>  | Indicates if the transition must be applied on the initial render of the node. | <code>boolean</code> | <code>true</code>  |
| <code>tag</code>     | The tag of the node to render to the DOM.                                      | <code>string</code>  | <code>'div'</code> |
| <code>stagger</code> | The time in ms to stagger each item.                                           | <code>number</code>  | <code>25</code>    |

## Slots

| Name                 | Description | Bindings<br />(name - type - description) |
| -------------------- | ----------- | ----------------------------------------- |
| <code>default</code> |             | None                                      |

The Staggered fade and slide components works as the normal fade and slide components, but it also
adds a configurable delay to each transition.

## Example

### Used with animatable components

```vue
<AnimatableComponent :animation="StaggeredFadeAndSlide" />
```

### Used as a regular component:

This components exposes all the props and events of the Staggering transition group, like the `tag`
or the `stagger` props:

```vue
<StaggeredFadeAndSlide tag="ul" :stagger="50">
  <li key="1">Element to animate</li>
  <li key="2">Element to animate</li>
  <li key="3">Element to animate</li>
</StaggeredFadeAndSlide>
```
