---

title: AllFilter

---

# AllFilter

This component receives a required `facet` with
@empathyco/x-types#BooleanFilter as prop and renders a button, which
on clicked emits the FacetsXEvents.UserClickedAllFilter event. By default
the rendered button displays a message with the facet label but this content is customizable
through the default slot.

## Props

| Name               | Description     | Type               | Default       |
| ------------------ | --------------- | ------------------ | ------------- |
| <code>facet</code> | The facet data. | <code>Facet</code> | <code></code> |

## Slots

| Name                 | Description                             | Bindings<br />(name - type - description) |
| -------------------- | --------------------------------------- | ----------------------------------------- |
| <code>default</code> | The content to render inside the button | <br />                                    |

## Events

A list of events that the component will emit:

- [`UserClickedAllFilter`](https://github.com/empathyco/x/blob/main/packages/x-components/src/wiring/events.types.ts):
  the event is emitted after the user clicks the button. The event payload is the id of the facet
  that this `AllFilter` component corresponds to.

## Examples

This component receives a required `facet` as prop and renders a button, which on clicked emits the
UserClickedAllFilter event. By default the rendered button displays a message with the facet label
but this content is customizable through the default slot.

### Basic usage

```vue
<AllFilter :facet="facet" />
```

### Customizing its content

```vue
<AllFilter v-slot="{ facet }" :facet="facet">
  Select all {{ facet.label }}
</AllFilter>
```

### Basic example within facets

```vue
<Facets>
  <template #default="{ facet }">
    <AllFilter :facet="facet" />
    <Filters v-slot="{ filter }" :filters="facet.filters">
      <SimpleFilter :filter="filter" />
    </Filters>
  </template>
</Facets>
```

### Custom example within facets

```vue
<Facets>
  <template #default="{ facet }">
    <AllFilter v-slot="{ facet }" :facet="facet">
      Select all {{ facet.label }}
    </AllFilter>
    <Filters v-slot="{ filter }" :filters="facet.filters">
      <SimpleFilter :filter="filter" />
    </Filters>
  </template>
</Facets>
```
