---

title: NumberRangeFilter

---

# NumberRangeFilter

Renders a number range filter, emitting the needed events when clicked.

## Props

| Name                     | Description                                                                | Type                                           | Default               |
| ------------------------ | -------------------------------------------------------------------------- | ---------------------------------------------- | --------------------- |
| <code>filter</code>      | The filter data to render.                                                 | <code>NumberRangeFilterModel</code>            | <code></code>         |
| <code>clickEvents</code> | Additional events, with their payload, to emit when the filter is clicked. | <code>Partial<XEventsTypes></code>             | <code></code>         |
| <code>cssClasses</code>  | Inheritance CSS classes.                                                   | <code>(string \| Dictionary<boolean>)[]</code> | <code>() => []</code> |

## Slots

| Name                 | Description                             | Bindings<br />(name - type - description)                                                                                                                                                                                                                                                                                                                    |
| -------------------- | --------------------------------------- | ------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------ |
| <code>default</code> | The control element to render           | **filter** <code>Filter</code> - The filter data<br />**clickFilter** <code>() => void</code> - Method that will invoke the needed actions after the user<br />**cssClasses** <code>Object</code> - Object containing CSS classes to add to the button<br />**isDisabled** <code>Boolean</code> - True if the filter shouldn't be able to be selected by the |
| <code>label</code>   | The content to render inside the button | **filter** <code>Filter</code> - The filter data                                                                                                                                                                                                                                                                                                             |

## Events

This component emits the following events:

- [`UserClickedAFilter`](https://github.com/empathyco/x/blob/main/packages/x-components/src/wiring/events.types.ts):
  the event is emitted after the user clicks the button, using the `filter` prop as its payload.
- [`UserClickedANumberRangeFilter`](https://github.com/empathyco/x/blob/main/packages/x-components/src/wiring/events.types.ts):
  the event is emitted after the user clicks the button, using the `filter` prop as its payload.

## See it in action

This component renders a button which, on clicked, emits the `UserClickedAFilter` and the
`UserClickedANumberRangeFilter` events. By default, it renders the filter label as the button text.

The `filter` prop is required. The `clickEvents` prop is optional and allows configuring the events
to emit on click.

```vue
<template>
  <NumberRangeFilter :filter="filter" />
</template>

<script>
import { NumberRangeFilter } from '@empathyco/x-components/facets'

export default {
  name: 'NumberRangeFilterTest',
  components: {
    NumberRangeFilter,
  },
  date() {
    return {
      filter: {
        id: `price:1-10`,
        modelName: 'NumberRangeFilter',
        label: `From 1 to 10`,
        facetId: 'price',
        range: {
          min: 1,
          max: 10,
        },
        selected: false,
      },
    }
  },
}
</script>
```

### Playing with props

Configuring the events to emit when the filter is clicked.

```vue
<template>
  <NumberRangeFilter :clickEvents="{ UserClickedANumberRangeFilter: filter }" :filter="filter" />
</template>

<script>
import { NumberRangeFilter } from '@empathyco/x-components/facets'

export default {
  name: 'NumberRangeFilterTest',
  components: {
    NumberRangeFilter,
  },
  date() {
    return {
      filter: {
        id: `price:1-10`,
        modelName: 'NumberRangeFilter',
        label: `From 1 to 10`,
        facetId: 'price',
        range: {
          min: 1,
          max: 10,
        },
        selected: false,
      },
    }
  },
}
</script>
```

### Customizing its contents

```vue
<template>
  <NumberRangeFilter :filter="filter" v-slot="{ filter }">
    <img src="checkbox.png" />
    <span>{{ filter.label }}</span>
  </NumberRangeFilter>
</template>

<script>
import { NumberRangeFilter } from '@empathyco/x-components/facets'

export default {
  name: 'NumberRangeFilterTest',
  components: {
    NumberRangeFilter,
  },
  date() {
    return {
      filter: {
        id: `price:1-10`,
        modelName: 'NumberRangeFilter',
        label: `From 1 to 10`,
        facetId: 'price',
        range: {
          min: 1,
          max: 10,
        },
        selected: false,
      },
    }
  },
}
</script>
```
