---

title: SimpleFilter

---

# SimpleFilter

Renders a simple filter, emitting the needed events when clicked.

## Props

| Name                     | Description                                                                | Type                                           | Default               |
| ------------------------ | -------------------------------------------------------------------------- | ---------------------------------------------- | --------------------- |
| <code>filter</code>      | The filter data to render.                                                 | <code>SimpleFilterModel</code>                 | <code></code>         |
| <code>clickEvents</code> | Additional events, with their payload, to emit when the filter is clicked. | <code>Partial<XEventsTypes></code>             | <code></code>         |
| <code>cssClasses</code>  | Inheritance CSS classes.                                                   | <code>(string \| Dictionary<boolean>)[]</code> | <code>() => []</code> |

## Slots

| Name                 | Description                             | Bindings<br />(name - type - description)                                                                                                                                                                                                                                                                                                                    |
| -------------------- | --------------------------------------- | ------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------ |
| <code>default</code> | The control element to render           | **filter** <code>Filter</code> - The filter data<br />**clickFilter** <code>() => void</code> - Method that will invoke the needed actions after the user<br />**isDisabled** <code>Boolean</code> - True if the filter shouldn't be able to be selected by the<br />**cssClasses** <code>Object</code> - Object containing CSS classes to add to the button |
| <code>label</code>   | The content to render inside the button | **filter** <code>Filter</code> - The filter data                                                                                                                                                                                                                                                                                                             |

## Events

A list of events that the component will emit:

- [`UserClickedAFilter`](https://github.com/empathyco/x/blob/main/packages/x-components/src/wiring/events.types.ts):
  the event is emitted after the user clicks the button, using the `filter` prop as its payload.
- [`UserClickedASimpleFilter`](https://github.com/empathyco/x/blob/main/packages/x-components/src/wiring/events.types.ts):
  the event is emitted after the user clicks the button, using the `filter` prop as its payload.

## See it in action

This component renders a button, which on clicked emits the `UserClickedAFilter` and the
`UserClickedASimpleFilter` events. By default, it renders a `button` with the `filter.label`
property as text.

The `filter` prop is required. The `clickEvents` prop is optional and allows configuring the events
to emit on click.

```vue
<template>
  <SimpleFilter :filter="filter" />
</template>

<script>
import { SimpleFilter } from '@empathyco/x-components/facets'

export default {
  name: 'SimpleFilterTest',
  components: {
    SimpleFilter,
  },
  data() {
    return {
      filter: {
        modelName: 'SimpleFilter',
        selected: false,
        id: 'category:shirts',
        value: 'category:shirts',
        facetId: 'category',
        totalResults: 10,
      },
    }
  },
}
</script>
```

### Playing with props

Configuring the events to emit when the filter is clicked.

```vue
<template>
  <SimpleFilter :clickEvents="{ UserClickedASimpleFilter: filter }" :filter="filter" />
</template>

<script>
import { SimpleFilter } from '@empathyco/x-components/facets'

export default {
  name: 'SimpleFilterTest',
  components: {
    SimpleFilter,
  },
  data() {
    return {
      filter: {
        modelName: 'SimpleFilter',
        selected: false,
        id: 'category:shirts',
        value: 'category:shirts',
        facetId: 'category',
        totalResults: 10,
      },
    }
  },
}
</script>
```

### Rendering an input

You can change the rendered control using the default slot. Note that because of the current Vue
limitations, you must only render one single root node in this slot. There you will receive all the
data and methods needed:

```vue
<template>
  <SimpleFilter v-slot="{ filter, clickFilter, isDisabled, cssClasses }" :filter="filter">
    <label :class="cssClasses">
      <input :checked="filter.selected" type="checkbox" @change="clickFilter" />
      {{ filter.label }}
    </label>
  </SimpleFilter>
</template>

<script>
import { SimpleFilter } from '@empathyco/x-components/facets'

export default {
  name: 'SimpleFilterTest',
  components: {
    SimpleFilter,
  },
  data() {
    return {
      filter: {
        modelName: 'SimpleFilter',
        selected: false,
        id: 'category:shirts',
        value: 'category:shirts',
        facetId: 'category',
        label: 'Shirts',
        totalResults: 10,
      },
    }
  },
}
</script>
```

### Changing default button content

You can change the content rendered by the default button using the `label` slot. There you will
receive the filter data.

```vue
<template>
  <SimpleFilter :filter="filter">
    <template #label="{ filter }">
      <img :src="`imgs/filters/${filter.id}.png`" />
      <span>{{ filter.label }}</span>
    </template>
  </SimpleFilter>
</template>

<script>
import { SimpleFilter } from '@empathyco/x-components/facets'

export default {
  name: 'SimpleFilterTest',
  components: {
    SimpleFilter,
  },
  data() {
    return {
      filter: {
        modelName: 'SimpleFilter',
        selected: false,
        id: 'category:shirts',
        value: 'category:shirts',
        facetId: 'category',
        label: 'Shirts',
        totalResults: 10,
      },
    }
  },
}
</script>
```
