---

title: SelectedFilters

---

# SelectedFilters

Provides a scoped slot with the selected filters from every facet, or from the facet which
facet id is passed as property.

The default slot renders the length of the selected filters array.
The property "alwaysVisible" handles if the component is rendered if no filters are selected.

## Props

| Name                       | Description                                                            | Type                            | Default       |
| -------------------------- | ---------------------------------------------------------------------- | ------------------------------- | ------------- |
| <code>facetsIds</code>     | Array of facets ids used to get the selected filters for those facets. | <code>Array<Facet['id']></code> | <code></code> |
| <code>alwaysVisible</code> | Flag to render the component even if there are no filters selected.    | <code>boolean</code>            | <code></code> |

## Examples

Provides a scoped slot with the selected filters from every facet, or from the facet which facet id
is passed as property.

The default slot renders the length of the selected filters array.

### Basic usage

```vue
<SelectedFilters />
```

### Always visible

If "alwaysVisible" is true, the component is rendered no matter if there are some filter selected.
If "alwaysVisible" is false (default), the component is rendered if there are some filter selected.

```vue
<SelectedFilters />
```

Output:

```html
<div class="x-selected-filters">1</div>
```

### Customizing its content

In this example, renders a custom message using the default scoped slot.

```vue
<SelectedFilters>
  <template #default="{ selectedFilters }">
    Selected filters: {{ selectedFilters.length }}
  </template>
</SelectedFilters>
```

Output:

```html
<div class="x-selected-filters">Selected filters: 1</div>
```

In this example, the selected filters are filtered by the facetsIds property.

```vue
<SelectedFilters :facetsIds="['brand_facet']" />
```

```vue
<SelectedFilters :facetsIds="['brand_facet', 'gender_facet']">
  <template #default="{ selectedFilters }">
    Selected filters: {{ selectedFilters.length }}
  </template>
</SelectedFilters>
```
