---

title: RelatedTag

---

# RelatedTag

This component renders a related tag for a query. A related tag is a descriptive keyword
related to the current query to fine-tune the search. For example, if you are searching
for _lego_, a related tag could be _city_, refining the search with _lego city_.

## Props

| Name                          | Description                                                 | Type                         | Default            |
| ----------------------------- | ----------------------------------------------------------- | ---------------------------- | ------------------ |
| <code>highlightCurated</code> | Indicates if the curated related tag should be highlighted. | <code>boolean</code>         | <code>false</code> |
| <code>relatedTag</code>       | The related tag model data.                                 | <code>RelatedTagModel</code> | <code></code>      |

## Slots

| Name                 | Description                                                  | Bindings<br />(name - type - description)                                                                                                                                                                                     |
| -------------------- | ------------------------------------------------------------ | ----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- |
| <code>default</code> | Custom content that replaces the RelatedTag default content. | **relatedTag** <code>RelatedTag</code> - Related tag data.<br />**isSelected** <code>boolean</code> - Related tag status.<br />**shouldHighlightCurated** <code>boolean</code> - True if the curated RTs should be displayed. |

## Dynamic classes

`RelatedTag` uses the following dynamic CSS classes so you can style it when is:

- Selected: `x-related-tag--is-selected`.
- Curated: `x-related-tag--is-curated`.

## Events

This component emits the following events:

- [`UserDeselectedARelatedTag`](https://github.com/empathyco/x/blob/main/packages/x-components/src/wiring/events.types.ts)
- [`UserPickedARelatedTag`](https://github.com/empathyco/x/blob/main/packages/x-components/src/wiring/events.types.ts)
- [`UserSelectedARelatedTag`](https://github.com/empathyco/x/blob/main/packages/x-components/src/wiring/events.types.ts)

## See it in action

<!-- prettier-ignore-start -->
:::warning Backend service required
The QuerySignals microservice must be implemented.
:::
<!-- prettier-ignore-end -->

In this example related tag data is passed as a prop.

_Here you can see how the RelatedTag component is rendered._

```vue live
<template>
  <RelatedTag :relatedTag="tag" />
</template>

<script>
import { RelatedTag } from '@empathyco/x-components/related-tags'

export default {
  name: 'RelatedTagDemo',
  components: {
    RelatedTag,
  },
  data() {
    return {
      tag: {
        modelName: 'RelatedTag',
        query: 'high heel',
        isCurated: false,
        tag: 'heel',
      },
    }
  },
}
</script>
```

### Play with default slot

In this example, an HTML span element is passed in the `default` slot.

_See how the related tag can be rendered._

```vue live
<template>
  <RelatedTag :relatedTag="tag" #default="{ relatedTag }">
    <span :aria-label="relatedTag.tag">{{ relatedTag.tag }}</span>
  </RelatedTag>
</template>

<script>
import { RelatedTag } from '@empathyco/x-components/related-tags'

export default {
  name: 'RelatedTagDemo',
  components: {
    RelatedTag,
  },
  data() {
    return {
      tag: {
        modelName: 'RelatedTag',
        query: 'high heel',
        isCurated: false,
        tag: 'heel',
      },
    }
  },
}
</script>
```

### Play with events

In this example, the [`UserSelectedARelatedTag`](./../../api/x-components.relatedtagsxevents.md)
event is implemented, as illustrated by the “Tag” message returned.

_See how the event is triggered when the related tag is clicked._

```vue live
<template>
  <RelatedTag :relatedTag="tag" @UserSelectedARelatedTag="alertRelatedTag" />
</template>

<script>
import { RelatedTag } from '@empathyco/x-components/related-tags'

export default {
  name: 'RelatedTagDemo',
  components: {
    RelatedTag,
  },
  data() {
    return {
      tag: {
        modelName: 'RelatedTag',
        query: 'high heel',
        isCurated: false,
        tag: 'heel',
      },
    }
  },
  methods: {
    alertRelatedTag(relatedTag) {
      alert(`You have clicked the related tag: ${relatedTag.query}`)
    },
  },
}
</script>
```
