---

title: SearchInputPlaceholder

---

# SearchInputPlaceholder

## Props

| Name                             | Description                                                                             | Type                       | Default                                              |
| -------------------------------- | --------------------------------------------------------------------------------------- | -------------------------- | ---------------------------------------------------- |
| <code>messages</code>            | List of messages to animate.                                                            | <code>string[]</code>      | <code></code>                                        |
| <code>animation</code>           | Animation component used for the messages.                                              | <code>AnimationProp</code> | <code>() => animateTranslate('bottom-to-top')</code> |
| <code>animationIntervalMs</code> | Time in milliseconds during which each message is visible.                              | <code>number</code>        | <code>1500</code>                                    |
| <code>animateOnlyOnHover</code>  | Whether the messages animation is active only when hovering the search input or always. | <code>boolean</code>       | <code></code>                                        |

## See it in action

Here a basic example of how the animated search input placeholder is rendered.

```vue live
<template>
  <div style="position: relative; overflow: hidden;">
    <SearchInputPlaceholder
      style="position: absolute; height: 100%; pointer-events: none;"
      :messages="placeholderMessages"
    />
    <SearchInput />
  </div>
</template>

<script>
import { SearchInput, SearchInputPlaceholder } from '@empathyco/x-components/search-box'

export default {
  name: 'SearchInputPlaceholderDemo',
  components: {
    SearchInput,
    SearchInputPlaceholder,
  },
  data: function () {
    return {
      placeholderMessages: [
        'Find shirts',
        'Find shoes',
        'Find watches',
        'Find handbags',
        'Find sunglasses',
      ],
    }
  },
}
</script>
```

### Animating only on hover

In this example, the placeholder is configured to animate only when the user hovers in the search
input, showing the first message of the array the rest of the time.

```vue live
<template>
  <div style="position: relative; overflow: hidden;">
    <SearchInputPlaceholder
      style="position: absolute; height: 100%; pointer-events: none;"
      :messages="placeholderMessages"
      :animate-only-on-hover="true"
    />
    <SearchInput />
  </div>
</template>

<script>
import { SearchInput, SearchInputPlaceholder } from '@empathyco/x-components/search-box'

export default {
  name: 'SearchInputPlaceholderDemo',
  components: {
    SearchInput,
    SearchInputPlaceholder,
  },
  data: function () {
    return {
      placeholderMessages: [
        'Find shirts',
        'Find shoes',
        'Find watches',
        'Find handbags',
        'Find sunglasses',
      ],
    }
  },
}
</script>
```
