import { defineComponent } from 'vue';
import { AnimationProp } from '../../types/animation-prop.js';
import BaseEventsModal from './base-events-modal.vue.js';

/**
 * A specialised version of a modal component, made to contain a full search application.
 *
 * @public
 */
var _sfc_main = defineComponent({
    components: {
        BaseEventsModal,
    },
    props: {
        /**
         * Animation to use for opening/closing the modal.
         *
         * @public
         */
        animation: {
            type: AnimationProp,
        },
        /**
         * Events to listen for closing the main modal.
         */
        closeEvents: {
            type: Array,
            default: () => ['UserClickedCloseX', 'UserClickedOutOfMainModal'],
        },
        /**
         * Determines if the focused element changes to one inside the modal when it opens. Either the
         * first element with a positive tabindex or just the first focusable element.
         */
        focusOnOpen: {
            type: Boolean,
            default: false,
        },
        /**
         * Events to listen for opening the main modal.
         */
        openEvents: {
            type: Array,
            default: () => ['UserClickedOpenX', 'UserOpenXProgrammatically'],
        },
        /**
         * Event to be emitted by the modal when clicked out of its content.
         */
        outOfModalClickEvent: {
            type: String || null,
            default: 'UserClickedOutOfMainModal',
        },
    },
});

export { _sfc_main as default };
//# sourceMappingURL=main-modal.vue2.js.map
