import { defineComponent, computed } from 'vue';
import { facetsXModule } from '../../x-module.js';
import _sfc_main$1 from './renderless-filter.vue.js';

/**
 * Renders a number range filter, emitting the needed events when clicked.
 *
 * @public
 */
var _sfc_main = defineComponent({
    name: 'NumberRangeFilter',
    xModule: facetsXModule.name,
    components: { RenderlessFilter: _sfc_main$1 },
    inheritAttrs: false,
    props: {
        /** The filter data to render. */
        filter: {
            type: Object,
            required: true,
        },
        /**
         * Additional events, with their payload, to emit when the filter is clicked.
         *
         * @public
         */
        clickEvents: Object,
        /** Inheritance CSS classes. */
        cssClasses: {
            type: Array,
            default: () => [],
        },
    },
    setup(props) {
        /**
         * The {@link XEventsTypes} to emit.
         *
         * @returns The events to emit when clicked.
         * @internal
         */
        const innerClickEvents = computed(() => ({
            UserClickedANumberRangeFilter: props.filter,
            ...props.clickEvents,
        }));
        /**
         * Dynamic CSS classes to apply to the component.
         *
         * @returns The dynamic CSS classes to apply to the component.
         * @internal
         */
        const innerCssClasses = computed(() => [
            'x-number-range-filter',
            { 'x-number-range-filter--is-selected': props.filter.selected },
            ...props.cssClasses,
        ]);
        return {
            innerClickEvents,
            innerCssClasses,
        };
    },
});

export { _sfc_main as default };
//# sourceMappingURL=number-range-filter.vue2.js.map
