import { defineComponent, computed } from 'vue';
import { facetsXModule } from '../../x-module.js';
import _sfc_main$1 from './renderless-filter.vue.js';

/**
 * Renders a simple filter, emitting the needed events when clicked.
 *
 * @public
 */
var _sfc_main = defineComponent({
    name: 'SimpleFilter',
    xModule: facetsXModule.name,
    components: { RenderlessFilter: _sfc_main$1 },
    inheritAttrs: false,
    props: {
        /** The filter data to render. */
        filter: {
            type: Object,
            required: true,
        },
        /** Additional events, with their payload, to emit when the filter is clicked. */
        clickEvents: Object,
        /** Inheritance CSS classes. */
        cssClasses: {
            type: Array,
            default: () => [],
        },
    },
    setup(props) {
        /** The {@link XEventsTypes} to emit. */
        const innerClickEvents = computed(() => ({
            UserClickedASimpleFilter: props.filter,
            ...props.clickEvents,
        }));
        /** CSS classes to apply to the element. */
        const innerCssClasses = computed(() => [
            'x-simple-filter',
            { 'x-simple-filter--is-selected': props.filter.selected },
            ...props.cssClasses,
        ]);
        return {
            innerClickEvents,
            innerCssClasses,
        };
    },
});

export { _sfc_main as default };
//# sourceMappingURL=simple-filter.vue2.js.map
