import { defineComponent, h } from 'vue';
import { useFacets } from '../../composables/use-facets.js';
import { facetsXModule } from '../../x-module.js';

/**
 * Provides a scoped slot with the selected filters from every facet, or from the facet which
 * facet id is passed as property.
 *
 * The default slot renders the length of the selected filters array.
 * The property "alwaysVisible" handles if the component is rendered if no filters are selected.
 *
 * @public
 */
var _sfc_main = defineComponent({
    name: 'SelectedFilters',
    xModule: facetsXModule.name,
    props: {
        /** Array of facets ids used to get the selected filters for those facets. */
        facetsIds: Array,
        /** Flag to render the component even if there are no filters selected. */
        alwaysVisible: Boolean,
    },
    setup(props, { slots }) {
        const { selectedFilters, isVisible } = useFacets(props);
        return () => isVisible.value
            ? (slots.default?.({ selectedFilters: selectedFilters.value })[0] ??
                h('span', `${selectedFilters.value.length}`))
            : '';
    },
});

export { _sfc_main as default };
//# sourceMappingURL=selected-filters.vue.js.map
