import { isBooleanFilter } from '@empathyco/x-types';
import { defineComponent, computed, provide } from 'vue';
import { isArrayEmpty } from '../../../../utils/array.js';
import '../../../../utils/storage.js';
import { useFiltersInjection } from '../../composables/use-filters-injection.js';
import { facetsXModule } from '../../x-module.js';

/**
 * Component that sorts a list of filters and returns them using the default scoped slot.
 *
 * @public
 */
var _sfc_main = defineComponent({
    name: 'SortedFilters',
    xModule: facetsXModule.name,
    props: {
        /**
         * The list of filters to be rendered as slots.
         *
         * @public
         */
        filters: Array,
        /**
         * This prop is used in the `HierarchicalFilter` component and only in that case. It is necessary
         * to make the `renderedFilters` to return only the filters of each level of the hierarchy.
         *
         * @public
         */
        parentId: {
            type: String,
            required: false,
        },
    },
    setup(props, { slots }) {
        const renderedFilters = useFiltersInjection(props);
        /**
         * An array of filters with the selected filters at the beginning of the list.
         *
         * @returns Array of filters.
         * @internal
         */
        const sortedFilters = computed(() => {
            if (!isArrayEmpty(renderedFilters.value) && isBooleanFilter(renderedFilters.value[0])) {
                return [...renderedFilters.value].sort(({ selected }) => {
                    return selected ? -1 : 1;
                });
            }
            return renderedFilters.value;
        });
        provide('filters', sortedFilters);
        return () => slots.default?.({ filters: sortedFilters.value })[0] ?? '';
    },
});

export { _sfc_main as default };
//# sourceMappingURL=sorted-filters.vue.js.map
