import { setConfig, mergeConfig } from '../../../store/utils/config-store.utils.js';
import { setQuery } from '../../../store/utils/query.utils.js';
import { setStatus } from '../../../store/utils/status-store.utils.js';
import { cancelFetchAndSaveNextQueries, fetchAndSaveNextQueries } from './actions/fetch-and-save-next-queries.action.js';
import { fetchAndSaveNextQueryPreview } from './actions/fetch-and-save-next-query-preview.action.js';
import { fetchNextQueries } from './actions/fetch-next-queries.action.js';
import { fetchNextQueryPreview } from './actions/fetch-next-query-preview.action.js';
import { setQueryFromLastHistoryQuery } from './actions/set-query-from-last-history-query.action.js';
import { setUrlParams } from './actions/set-url-params.action.js';
import { query } from './getters/next-queries-query.getter.js';
import { nextQueries } from './getters/next-queries.getter.js';
import { request } from './getters/request.getter.js';

/**
 * {@link XStoreModule} For the next-queries module.
 *
 * @internal
 */
const nextQueriesXStoreModule = {
    state: () => ({
        query: '',
        nextQueries: [],
        searchedQueries: [],
        relatedTags: [],
        status: 'initial',
        config: {
            maxItemsToRequest: 20,
            hideSessionQueries: true,
            loadOnInit: true,
            maxPreviewItemsToRequest: 8,
        },
        params: {},
        resultsPreview: {},
    }),
    getters: {
        request,
        nextQueries,
        query,
    },
    mutations: {
        setQuery,
        setNextQueries(state, nextQueries) {
            state.nextQueries = nextQueries;
        },
        setSearchedQueries(state, searchedQueries) {
            state.searchedQueries = searchedQueries;
        },
        setRelatedTags(state, relatedTags) {
            state.relatedTags = relatedTags;
        },
        setStatus,
        setParams(state, params) {
            state.params = params;
        },
        setResultsPreview(state, resultsPreview) {
            state.resultsPreview = { ...state.resultsPreview, ...resultsPreview };
        },
        resetResultsPreview(state) {
            state.resultsPreview = {};
        },
        setConfig,
        mergeConfig,
    },
    actions: {
        cancelFetchAndSaveNextQueries,
        fetchAndSaveNextQueries,
        fetchNextQueries,
        setQueryFromLastHistoryQuery,
        setUrlParams,
        fetchNextQueryPreview,
        fetchAndSaveNextQueryPreview,
    },
};

export { nextQueriesXStoreModule };
//# sourceMappingURL=module.js.map
