import { computed } from 'vue';
import { XPlugin } from '../../../plugins/x-plugin.js';

/**
 * Composable helpers for the QueriesPreview module.
 *
 * @returns Composable with helpers.
 *
 * @public
 */
const useQueriesPreview = () => {
    const store = XPlugin.store;
    const loadedQueriesPreview = computed(
    // eslint-disable-next-line ts/no-unsafe-member-access,ts/no-unsafe-return
    () => store.getters['x/queriesPreview/loadedQueriesPreview']);
    const loadedQueries = computed(() => {
        return Object.keys(loadedQueriesPreview.value);
    });
    /**
     * Checks if the query passed has results in the queries preview.
     *
     * @param query - The query to check.
     * @returns True if the query has results.
     */
    const isQueryLoadedInPreview = (query) => {
        return loadedQueries.value.includes(query);
    };
    /**
     * Checks if any of the queries passed have results in the queries previews.
     *
     * @param queries - The queries to check.
     * @returns True if some query has results.
     */
    const isAnyQueryLoadedInPreview = (queries) => {
        return queries.some(isQueryLoadedInPreview);
    };
    return {
        isAnyQueryLoadedInPreview,
        isQueryLoadedInPreview,
    };
};

export { useQueriesPreview };
//# sourceMappingURL=use-queries-preview.composable.js.map
