import { namespacedWireCommit, namespacedWireDispatch } from '../../wiring/namespaced-wires.factory.js';
import { createWiring } from '../../wiring/wiring.utils.js';

/**
 * `queriesPreview` {@link XModuleName | XModule name}.
 *
 * @internal
 */
const moduleName = 'queriesPreview';
/**
 * WireCommit for {@link QueriesPreviewXModule}.
 *
 * @internal
 */
const wireCommit = namespacedWireCommit(moduleName);
/**
 * WireDispatch for {@link QueriesPreviewXModule}.
 *
 * @internal
 */
const wireDispatch = namespacedWireDispatch(moduleName);
/**
 * Requests and stores the cacheable query preview results.
 *
 * @public
 */
const fetchAndSaveQueryPreviewWire = wireDispatch('fetchAndSaveQueryPreview');
/**
 * Clears a query preview from queries preview module.
 *
 * @public
 */
const clearQueryPreviewWire = wireCommit('clearQueryPreview');
/**
 * Sets the queries preview state `params`.
 *
 * @public
 */
const setQueriesPreviewExtraParamsWire = wireCommit('setParams');
/**
 * Updates the state with the selected query preview object.
 *
 * @public
 */
const setSelectedQueryPreviewWire = wireCommit('setSelectedQueryPreview');
/**
 * Clears the selected query preview object from queries preview module.
 *
 * @public
 */
const clearSelectedQueryPreviewWire = wireCommit('setSelectedQueryPreview', null);
/**
 * Adds a new instance in a query preview.
 *
 * @public
 */
const addQueryPreviewInstanceWire = wireCommit('addQueryPreviewInstance');
/**
 * Removes an instance in a query preview.
 *
 * @public
 */
const removeQueryPreviewInstanceWire = wireCommit('removeQueryPreviewInstance');
/**
 * Wiring configuration for the {@link QueriesPreviewXModule | queriesPreview module}.
 *
 * @internal
 */
const queriesPreviewWiring = createWiring({
    QueryPreviewRequestUpdated: {
        fetchAndSaveQueryPreviewWire,
    },
    NonCacheableQueryPreviewUnmounted: {
        clearQueryPreviewWire,
    },
    UserAcceptedAQueryPreview: {
        setSelectedQueryPreviewWire,
    },
    ExtraParamsChanged: {
        setQueriesPreviewExtraParamsWire,
    },
    UserClearedQuery: {
        clearSelectedQueryPreviewWire,
    },
    UserClickedCloseX: {
        clearSelectedQueryPreviewWire,
    },
    UserClickedOutOfMainModal: {
        clearSelectedQueryPreviewWire,
    },
    UserSelectedAHistoryQuery: {
        clearSelectedQueryPreviewWire,
    },
    QueryPreviewMounted: {
        addQueryPreviewInstanceWire,
    },
    QueryPreviewUnmounted: {
        removeQueryPreviewInstanceWire,
    },
});

export { addQueryPreviewInstanceWire, clearQueryPreviewWire, clearSelectedQueryPreviewWire, fetchAndSaveQueryPreviewWire, queriesPreviewWiring, removeQueryPreviewInstanceWire, setQueriesPreviewExtraParamsWire, setSelectedQueryPreviewWire };
//# sourceMappingURL=wiring.js.map
