import { defineComponent } from 'vue';
import BaseSuggestion from '../../../components/suggestions/base-suggestion.vue.js';
import '../../../composables/create-use-device.js';
import '@vue/devtools-api';
import '../../../plugins/devtools/timeline.devtools.js';
import '@empathyco/x-utils';
import 'rxjs/operators';
import 'rxjs';
import '../../../plugins/devtools/colors.utils.js';
import '../../../plugins/x-bus.js';
import '../../../plugins/x-plugin.js';
import 'vuex';
import { useGetter } from '../../../composables/use-getter.js';
import '@vueuse/core';
import { querySuggestionsXModule } from '../x-module.js';

/**
 * This component renders a suggestion for a query. A query suggestion is a recommended query
 * based on previous search queries. It contains the query itself and a set of filters associated.
 * For example, if you're searching for _shirt_, a query suggestion could be _long sleeve shirt_.
 *
 * @public
 */
var _sfc_main = defineComponent({
    name: 'QuerySuggestion',
    xModule: querySuggestionsXModule.name,
    components: { BaseSuggestion },
    props: {
        /** The suggestion to render. */
        suggestion: {
            type: Object,
            required: true,
        },
    },
    setup(props) {
        /** The normalized query of the query-suggestions module. */
        const query = useGetter('querySuggestions').normalizedQuery;
        /**
         * Emits {@link QuerySuggestionsXEvents.UserSelectedAQuerySuggestion} with the suggestion as
         * payload when selecting the query suggestion.
         */
        const suggestionSelectedEvents = {
            UserSelectedAQuerySuggestion: props.suggestion,
        };
        return {
            query,
            suggestionSelectedEvents,
        };
    },
});

export { _sfc_main as default };
//# sourceMappingURL=query-suggestion.vue2.js.map
