import { defineComponent, computed } from 'vue';
import { useGetter } from '../../../composables/use-getter.js';
import { AnimationProp } from '../../../types/animation-prop.js';
import { relatedTagsXModule } from '../x-module.js';
import RelatedTag from './related-tag.vue.js';

/**
 * This component renders a set of [`RelatedTag`](./x-components.related-tag) components by
 * default to select from after a query is performed to fine-tune search.
 * For example, if you are searching for *lego*, different related tags could be *city*,
 * friends*, or *harry potter*, refining the search with *lego city*, *lego friends*,
 * or *lego harry potter*.
 *
 * @public
 */
var _sfc_main = defineComponent({
    name: 'RelatedTags',
    xModule: relatedTagsXModule.name,
    components: {
        RelatedTag,
    },
    props: {
        /**
         * Animation component that will be used to animate the suggestion.
         *
         * @public
         */
        animation: {
            type: AnimationProp,
            default: 'ul',
        },
        /**
         * Number of related tags to be rendered.
         *
         * @public
         */
        maxItemsToRender: Number,
        /**
         * Flag to indicate if the curated tags should be displayed different.
         *
         * @public
         */
        highlightCurated: {
            type: Boolean,
            default: false,
        },
        /** Class inherited by content element. */
        itemClass: String,
    },
    setup(props) {
        const storedRelatedTags = useGetter('relatedTags').relatedTags;
        const relatedTags = computed(() => storedRelatedTags.value.slice(0, props.maxItemsToRender));
        return {
            relatedTags,
        };
    },
});

export { _sfc_main as default };
//# sourceMappingURL=related-tags.vue2.js.map
