/**
 * Helper method which creates the {@link RelatedTag} entity from the string array `tag` of the url.
 *
 * @param tags - List of tags from the url.
 * @param query - Query from the url.
 *
 * @returns A list of {@link RelatedTag | related tags}.
 */
function createRelatedTags(tags, query) {
    return tags.map(tag => ({
        tag,
        modelName: 'RelatedTag',
        query: query ? `${query} ${tag}` : '',
    }));
}
/**
 * Default implementation for the {@link RelatedTagsActions.setUrlParams}.
 *
 * @param context - The {@link https://vuex.vuejs.org/guide/actions.html | context} of the actions,
 * provided by Vuex.
 * @param context.commit - commit context.
 * @param urlParams - The url params from the url.
 * @param urlParams.query - query urlParams.
 * @param urlParams.tag - tag urlParams.
 *
 * @public
 */
const setUrlParams = ({ commit }, { query, tag }) => {
    commit('setSelectedRelatedTags', createRelatedTags(tag, query));
    commit('setQuery', query);
};

export { setUrlParams };
//# sourceMappingURL=set-url-params.action.js.map
