import { namespacedWireCommit, namespacedWireDispatch } from '../../wiring/namespaced-wires.factory.js';
import { mapWire } from '../../wiring/wires.operators.js';
import { createWiring } from '../../wiring/wiring.utils.js';

/**
 * `semanticQueries` {@link XModuleName | name}.
 *
 * @internal
 */
const moduleName = 'semanticQueries';
/**
 * WireCommit for {@link SemanticQueriesXModule}.
 *
 * @internal
 */
const wireCommit = namespacedWireCommit(moduleName);
/**
 * WireDispatch for {@link SemanticQueriesXModule}.
 *
 * @internal
 */
const wireDispatch = namespacedWireDispatch(moduleName);
/**
 * Requests and stores the semantic query results.
 *
 * @public
 */
const fetchAndSaveSemanticQueryWire = wireDispatch('fetchAndSaveSemanticQuery');
/**
 * Sets the query.
 *
 * @public
 */
const setQueryWire = wireCommit('setQuery');
/**
 * Sets the query taking the {@link SearchXEvents.SearchResponseChanged} payload.
 *
 * @public
 */
const setQueryFromSearchResponseChangedWire = mapWire(setQueryWire, ({ request: { query } }) => query);
/**
 * Clears the query.
 *
 * @public
 */
const clearQueryWire = wireCommit('setQuery', '');
/**
 * Sets the total results.
 *
 * @public
 */
const setTotalResultsWire = wireCommit('setTotalResults');
/** Sets the related prompts state `relatedTags`. */
const setSemanticQueriesRelatedTags = wireCommit('setSemanticQueriesRelatedTags');
/**
 * Sets the total results taking the {@link SearchXEvents.SearchResponseChanged} payload.
 *
 * @public
 */
const setTotalResultsFromSearchResponseChangedWire = mapWire(setTotalResultsWire, ({ totalResults }) => totalResults);
/**
 * Sets the semantic queries state `params`.
 *
 * @public
 */
const setSemanticQueriesExtraParamsWire = wireCommit('setParams');
/**
 * Wiring configuration for the {@link SemanticQueriesXModule | semanticQueries module}.
 *
 * @internal
 */
const semanticQueriesWiring = createWiring({
    UserClearedQuery: {
        clearQueryWire,
    },
    SemanticQueryRequestUpdated: {
        fetchAndSaveSemanticQueryWire,
    },
    ExtraParamsChanged: {
        setSemanticQueriesExtraParamsWire,
    },
    SearchResponseChanged: {
        setQueryFromSearchResponseChangedWire,
        setTotalResultsFromSearchResponseChangedWire,
    },
    SelectedRelatedTagsChanged: {
        setSemanticQueriesRelatedTags,
    },
});

export { clearQueryWire, fetchAndSaveSemanticQueryWire, semanticQueriesWiring, setQueryFromSearchResponseChangedWire, setQueryWire, setSemanticQueriesExtraParamsWire, setTotalResultsFromSearchResponseChangedWire, setTotalResultsWire };
//# sourceMappingURL=wiring.js.map
