import type { Result, ResultVariant } from '@empathyco/x-types';
import type { ListItem } from '../../utils/types';
/**
 * Type of the key passed to `provide` and `inject` to be type-safe. With this type
 * you can declare the type of the injected value directly in the injection key.
 *
 * @example
 * `const myKey: XInjectKey<Filter> = 'myFilter';`
 * `inject(myKey)`
 *
 * @public
 */
export interface XInjectKey<Type> extends String {
}
/**
 * It's used to identify the provided and injected `disable-animations`.
 *
 * @internal
 */
export declare const DISABLE_ANIMATIONS_KEY: XInjectKey<boolean | undefined>;
/**
 * It's used to identify the provided and injected `items`.
 *
 * @internal
 */
export declare const LIST_ITEMS_KEY: XInjectKey<ListItem[] | undefined>;
/**
 * It's used to identify the provided and injected `query`.
 *
 * @internal
 */
export declare const QUERY_KEY: XInjectKey<string | undefined>;
/**
 * It's used to identify the provided and injected `hasMoreItems`.
 *
 * @internal
 */
export declare const HAS_MORE_ITEMS_KEY: XInjectKey<boolean | undefined>;
/**
 * It's used to identify the provided and injected `result`.
 *
 * @internal
 */
export declare const RESULT_WITH_VARIANTS_KEY: XInjectKey<Result>;
/**
 * It's used to identify the provided and injected `selectedVariants` of a result.
 *
 * @internal
 */
export declare const SELECTED_VARIANTS_KEY: XInjectKey<ResultVariant[]>;
/**
 * It's used to identify the provided and injected `selectResultVariant` callback.
 *
 * @internal
 */
export declare const SELECT_RESULT_VARIANT_KEY: XInjectKey<(variant: ResultVariant, level?: number) => void>;
//# sourceMappingURL=injection.consts.d.ts.map