import type { Facet } from '@empathyco/x-types';
import type { Dictionary } from '@empathyco/x-utils';
import type { PropType } from 'vue';
/**
 * Custom interface to provide a slot name to a Facet.
 *
 * @internal
 */
interface RenderFacet {
    slotNameById: string;
    slotNameByModelName: string;
    facet: Facet;
}
/**
 * This component renders the list of facets stored in the Facets module. Facets can be rendered
 * differently based on their purpose and this can be achieved using the exposed slots:
 * - A default and required slot.
 * - A custom slot for each facet with the facetId as its name. This allows each facet to be
 * rendered differently based on its needs.
 *
 * @public
 */
declare const _default: import("vue").DefineComponent<{
    /** Array of facets ids used to get the selected filters for those facets. */
    facetsIds: PropType<(string | number)[]>;
    /** Flag to render the component even if there are no filters selected. */
    alwaysVisible: BooleanConstructor;
    /** Animation component that will be used to animate the facets. */
    animation: {
        type: (StringConstructor | ObjectConstructor | FunctionConstructor)[];
        default: string;
    };
    /**
     * Discriminates the facets rendered by this component. It expects a string containing facets
     * ids, comma separated. This property will include or exclude facets based on its value.
     * The default value is an empty string and the component will render all existing facets.
     *
     * @remarks
     * To behave as a `include`, simply set the facets ids, comma separated:
     * `existingFacets=[{ brand: ... }, category: { ... }, color: { ... }, price: { ... }]`
     * `renderableFacets="brand, category"`
     *
     * The component will render brand and category facets.
     *
     * On the other hand, to simulate an `exclude` behaviour and exclude a facet from being
     * rendered, append a '!' before its id:
     * `existingFacets=[{ brand: ... }, category: { ... }, color: { ... }, price: { ... }]`
     * `renderableFacets="!brand,!price"`
     *
     * The component will render category and color facets.
     */
    renderableFacets: StringConstructor;
}, {
    selectedFiltersByFacet: import("vue").ComputedRef<import("../..").FiltersByFacet>;
    hasFacets: import("vue").ComputedRef<boolean>;
    mappedFacets: import("vue").ComputedRef<Dictionary<RenderFacet>>;
    hasSlot: (name: string) => boolean;
}, unknown, {}, {}, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, {}, string, import("vue").PublicProps, Readonly<import("vue").ExtractPropTypes<{
    /** Array of facets ids used to get the selected filters for those facets. */
    facetsIds: PropType<(string | number)[]>;
    /** Flag to render the component even if there are no filters selected. */
    alwaysVisible: BooleanConstructor;
    /** Animation component that will be used to animate the facets. */
    animation: {
        type: (StringConstructor | ObjectConstructor | FunctionConstructor)[];
        default: string;
    };
    /**
     * Discriminates the facets rendered by this component. It expects a string containing facets
     * ids, comma separated. This property will include or exclude facets based on its value.
     * The default value is an empty string and the component will render all existing facets.
     *
     * @remarks
     * To behave as a `include`, simply set the facets ids, comma separated:
     * `existingFacets=[{ brand: ... }, category: { ... }, color: { ... }, price: { ... }]`
     * `renderableFacets="brand, category"`
     *
     * The component will render brand and category facets.
     *
     * On the other hand, to simulate an `exclude` behaviour and exclude a facet from being
     * rendered, append a '!' before its id:
     * `existingFacets=[{ brand: ... }, category: { ... }, color: { ... }, price: { ... }]`
     * `renderableFacets="!brand,!price"`
     *
     * The component will render category and color facets.
     */
    renderableFacets: StringConstructor;
}>>, {
    alwaysVisible: boolean;
    animation: string | Function | Record<string, any>;
}, {}>;
export default _default;
//# sourceMappingURL=facets.vue?vue&type=script&lang.d.ts.map