import type { EditableNumberRangeFilter as EditableNumberRangeFilterModel } from '@empathyco/x-types';
import type { PropType, Ref } from 'vue';
/**
 * Renders an editable number range filter. It has two input fields to handle min and max values,
 * emitting the needed events when clicked.
 *
 * It provides a default slot, with some utils bind, to customize the whole component; and two
 * named slots `apply-content` and `clear-content` to override each button content.
 *
 * If `instant` prop is true, the needed events are emitted immediately; else, apply button is
 * rendered to confirm to do it. False by default.
 *
 * If `clear` prop is true, clear button, which sets to null component min and max values, is
 * rendered. True by default.
 *
 * @public
 */
declare const _default: import("vue").DefineComponent<{
    /**
     * The filter data to render and edit.
     *
     * @public
     */
    filter: {
        type: PropType<EditableNumberRangeFilterModel>;
        required: true;
    };
    /**
     * If `instant` prop is true, the needed events are emitted immediately; else, apply button is
     * rendered to confirm to do it. False by default.
     *
     * @public
     */
    isInstant: BooleanConstructor;
    /**
     * If `clear` prop is true, clear button, which sets to null component min and max values, is
     * rendered. True by default.
     *
     * @public
     */
    hasClearButton: {
        type: BooleanConstructor;
        default: boolean;
    };
    /** Class inherited by content element. */
    inputsClass: StringConstructor;
    /** Class inherited by content element. */
    buttonsClass: StringConstructor;
}, {
    rangeFilterMin: string;
    rangeFilterMax: string;
    cssClasses: import("vue").ComputedRef<{
        'x-editable-number-range-filter--error': boolean;
    }>;
    min: Ref<number | null>;
    max: Ref<number | null>;
    setMin: (value: number) => void;
    setMax: (value: number) => void;
    emitUserModifiedFilter: () => void;
    clearValues: () => void;
    hasError: import("vue").ComputedRef<boolean>;
    isAnyRange: import("vue").ComputedRef<boolean>;
    renderClearButton: import("vue").ComputedRef<boolean>;
}, unknown, {}, {}, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, {}, string, import("vue").PublicProps, Readonly<import("vue").ExtractPropTypes<{
    /**
     * The filter data to render and edit.
     *
     * @public
     */
    filter: {
        type: PropType<EditableNumberRangeFilterModel>;
        required: true;
    };
    /**
     * If `instant` prop is true, the needed events are emitted immediately; else, apply button is
     * rendered to confirm to do it. False by default.
     *
     * @public
     */
    isInstant: BooleanConstructor;
    /**
     * If `clear` prop is true, clear button, which sets to null component min and max values, is
     * rendered. True by default.
     *
     * @public
     */
    hasClearButton: {
        type: BooleanConstructor;
        default: boolean;
    };
    /** Class inherited by content element. */
    inputsClass: StringConstructor;
    /** Class inherited by content element. */
    buttonsClass: StringConstructor;
}>>, {
    isInstant: boolean;
    hasClearButton: boolean;
}, {}>;
export default _default;
//# sourceMappingURL=editable-number-range-filter.vue?vue&type=script&lang.d.ts.map