import type { SimpleFilter as SimpleFilterModel } from '@empathyco/x-types';
import type { Dictionary } from '@empathyco/x-utils';
import type { PropType } from 'vue';
import type { XEventsTypes } from '../../../../wiring/events.types';
/**
 * Renders a simple filter, emitting the needed events when clicked.
 *
 * @public
 */
declare const _default: import("vue").DefineComponent<{
    /** The filter data to render. */
    filter: {
        type: PropType<SimpleFilterModel>;
        required: true;
    };
    /** Additional events, with their payload, to emit when the filter is clicked. */
    clickEvents: PropType<Partial<XEventsTypes>>;
    /** Inheritance CSS classes. */
    cssClasses: {
        type: PropType<(string | Dictionary<boolean>)[]>;
        default: () => never[];
    };
}, {
    innerClickEvents: import("vue").ComputedRef<{
        ColumnsNumberProvided?: number | undefined;
        RenderedColumnsNumberChanged?: number | undefined;
        SuggestionsDisplayed?: import("@empathyco/x-types").Suggestion[] | undefined;
        TogglePanelStateChanged?: boolean | undefined;
        UserAcceptedAQuery?: string | undefined;
        UserAcceptedSpellcheckQuery?: string | undefined;
        UserClickedAResult?: import("@empathyco/x-types").Result | undefined;
        UserClickedADisplayResult?: import("@empathyco/x-types").Result | undefined;
        UserClickedCloseEventsModal?: void | undefined;
        UserClickedCloseModal?: string | undefined;
        UserClickedCloseX?: void | undefined;
        UserClickedOutOfMainModal?: void | undefined;
        UserClickedColumnPicker?: number | undefined;
        UserClickedOpenEventsModal?: void | undefined;
        UserClickedOpenModal?: string | undefined;
        UserClickedOpenX?: void | undefined;
        UserClickedOutOfEventsModal?: void | undefined;
        UserClickedOutOfModal?: string | undefined;
        UserClickedPanelToggleButton?: string | undefined;
        UserClickedResultAddToCart?: import("@empathyco/x-types").Result | undefined;
        UserClickedAResultRating?: import("@empathyco/x-types").Result | undefined;
        UserClickedScrollToTop?: string | undefined;
        UserOpenXProgrammatically?: void | undefined;
        UserPressedArrowKey?: import("../../../..").ArrowKey | undefined;
        UserReachedEmpathizeTop?: void | undefined;
        UserSelectedAResultVariant?: {
            result: import("@empathyco/x-types").Result;
            variant: import("@empathyco/x-types").ResultVariant;
            level: number;
            queryPreviewHash: import("vue").ComputedRef<string> | null;
        } | undefined;
        UserSelectedASuggestion?: import("@empathyco/x-types").Suggestion | undefined;
        SnippetCallbackExecuted?: {
            event: keyof XEventsTypes;
            callbackReturn: unknown;
            payload: never;
            metadata: import("../../../..").WireMetadata;
        } | undefined;
        ModuleRegistered?: keyof import("../../../x-modules.types").XModulesTree | undefined;
        DeviceProvided?: string | null | undefined;
        EmpathizeClosed?: void | undefined;
        EmpathizeOpened?: void | undefined;
        UserClosedEmpathize?: void | undefined;
        UserChangedExtraParams?: Dictionary<unknown> | undefined;
        ExtraParamsChanged?: Dictionary<unknown> | undefined;
        ExtraParamsProvided?: Dictionary<unknown> | undefined;
        ExtraParamsInitialized?: Dictionary<unknown> | undefined;
        FacetsGroupChanged?: import("../..").FacetsGroup | undefined;
        FacetsGroupProvided?: import("../..").FacetsGroup | undefined;
        PreselectedFiltersProvided?: import("@empathyco/x-types").RawFilter[] | undefined;
        SelectedFiltersChanged?: import("@empathyco/x-types").Filter[] | undefined;
        SelectedFiltersForRequestChanged?: import("@empathyco/x-types").Filter[] | undefined;
        UserChangedSelectedFilters?: import("@empathyco/x-types").Filter[] | undefined;
        UserClickedAFilter?: import("@empathyco/x-types").Filter | undefined;
        UserClickedAHierarchicalFilter?: import("@empathyco/x-types").HierarchicalFilter | undefined;
        UserClickedANumberRangeFilter?: import("@empathyco/x-types").NumberRangeFilter | undefined;
        UserClickedASimpleFilter: SimpleFilterModel;
        UserClickedAllFilter?: [string | number] | undefined;
        UserModifiedEditableNumberRangeFilter?: import("@empathyco/x-types").EditableNumberRangeFilter | undefined;
        UserClickedClearAllFilters?: (string | number)[] | undefined;
        FacetsQueryChanged?: string | undefined;
        HistoryQueriesDisplayed?: import("@empathyco/x-types").HistoryQuery[] | undefined;
        HistoryQueriesQueryChanged?: string | undefined;
        HistoryQueriesStorageKeyChanged?: string | undefined;
        SessionHistoryQueriesChanged?: import("@empathyco/x-types").HistoryQuery[] | undefined;
        UserPressedClearHistoryQueries?: void | undefined;
        UserPressedRemoveHistoryQuery?: import("@empathyco/x-types").HistoryQuery | undefined;
        UserSelectedAHistoryQuery?: import("@empathyco/x-types").HistoryQuery | undefined;
        UserClickedEnableHistoryQueries?: void | undefined;
        UserClickedDisableHistoryQueries?: void | undefined;
        UserClickedConfirmDisableHistoryQueries?: void | undefined;
        UserClickedDismissDisableHistoryQueries?: void | undefined;
        IdentifierResultsChanged?: import("@empathyco/x-types").Result[] | undefined;
        IdentifierResultsRequestUpdated?: import("@empathyco/x-types").IdentifierResultsRequest | null | undefined;
        UserClickedAIdentifierResult?: import("@empathyco/x-types").Result | undefined;
        NextQueriesChanged?: import("@empathyco/x-types").NextQuery[] | undefined;
        NextQueriesDisplayed?: import("@empathyco/x-types").NextQuery[] | undefined;
        NextQueriesRequestUpdated?: import("@empathyco/x-types").NextQueriesRequest | null | undefined;
        UserSelectedANextQuery?: import("@empathyco/x-types").NextQuery | undefined;
        NextQueryPreviewMountedHook?: string | undefined;
        PopularSearchesRequestUpdated?: import("@empathyco/x-types").PopularSearchesRequest | undefined;
        PopularSearchDisplayed?: import("@empathyco/x-types").Suggestion[] | undefined;
        UserSelectedAPopularSearch?: import("@empathyco/x-types").Suggestion | undefined;
        QueryPreviewRequestUpdated?: import("@empathyco/x-types").SearchRequest | undefined;
        UserAcceptedAQueryPreview?: import("../../../queries-preview").QueryPreviewInfo | undefined;
        QueryPreviewUnselected?: Dictionary<unknown> | undefined;
        QueryPreviewMounted?: string | undefined;
        QueryPreviewUnmounted?: {
            queryPreviewHash: string;
            cache: boolean;
        } | undefined;
        QuerySuggestionsChanged?: import("@empathyco/x-types").Suggestion[] | undefined;
        QuerySuggestionsRequestUpdated?: import("@empathyco/x-types").QuerySuggestionsRequest | null | undefined;
        UserSelectedAQuerySuggestion?: import("@empathyco/x-types").Suggestion | undefined;
        RecommendationsChanged?: import("@empathyco/x-types").Result[] | undefined;
        RecommendationsRequestUpdated?: import("@empathyco/x-types").RecommendationsRequest | undefined;
        UserClickedARecommendation?: import("@empathyco/x-types").Result | undefined;
        RelatedTagsChanged?: import("@empathyco/x-types").RelatedTag[] | undefined;
        RelatedTagsRequestUpdated?: import("@empathyco/x-types").RelatedTagsRequest | null | undefined;
        SelectedRelatedTagsChanged?: import("@empathyco/x-types").RelatedTag[] | undefined;
        UserDeselectedARelatedTag?: import("@empathyco/x-types").RelatedTag | undefined;
        UserPickedARelatedTag?: import("@empathyco/x-types").RelatedTag | undefined;
        UserSelectedARelatedTag?: import("@empathyco/x-types").RelatedTag | undefined;
        ScrollRestoreSucceeded?: void | undefined;
        ScrollRestoreFailed?: void | undefined;
        UserAlmostReachedScrollEnd?: boolean | undefined;
        UserChangedScrollDirection?: import("../../../..").ScrollDirection | undefined;
        UserReachedScrollEnd?: boolean | undefined;
        UserReachedScrollStart?: boolean | undefined;
        UserScrolled?: number | undefined;
        UserScrolledToElement?: string | undefined;
        SearchBoxQueryChanged?: string | undefined;
        UserHoveredInSearchBox?: void | undefined;
        UserHoveredOutSearchBox?: void | undefined;
        UserBlurredSearchBox?: void | undefined;
        UserClearedQuery?: string | undefined;
        UserClickedSearchBox?: void | undefined;
        UserFocusedSearchBox?: void | undefined;
        UserIsTypingAQuery?: string | undefined;
        UserPressedClearSearchBoxButton?: void | undefined;
        UserPressedEnterKey?: string | undefined;
        UserPressedSearchButton?: string | undefined;
        UserTalked?: string | undefined;
        FacetsChanged?: import("@empathyco/x-types").Facet[] | undefined;
        PageChanged?: number | undefined;
        ReloadSearchRequested?: void | undefined;
        ResultsChanged?: import("@empathyco/x-types").Result[] | undefined;
        SearchRequestChanged?: import("../../../search").InternalSearchRequest | null | undefined;
        SearchRequestUpdated?: import("../../../search").InternalSearchRequest | null | undefined;
        SearchResponseChanged?: import("../../../search").InternalSearchResponse | undefined;
        SearchTaggingChanged?: import("@empathyco/x-types").TaggingRequest | undefined;
        SortChanged?: string | undefined;
        SpellcheckChanged?: string | undefined;
        UserClickedASort?: string | undefined;
        SelectedSortProvided?: string | undefined;
        UserClickedPartialQuery?: string | undefined;
        UserReachedResultsListEnd?: void | undefined;
        UserClickedARedirection?: import("@empathyco/x-types").Redirection | undefined;
        UserClickedAPromoted?: import("@empathyco/x-types").Promoted | undefined;
        UserClickedABanner?: import("@empathyco/x-types").Banner | undefined;
        UserClickedAbortARedirection?: void | undefined;
        UserSelectedAPage?: number | undefined;
        SemanticQueryRequestUpdated?: import("@empathyco/x-types").SemanticQueriesRequest | null | undefined;
        SemanticQueriesResponseChanged?: import("@empathyco/x-types").SemanticQuery[] | undefined;
        UserSelectedASemanticQuery?: import("@empathyco/x-types").SemanticQuery | undefined;
        ConsentChanged?: boolean | undefined;
        ConsentProvided?: boolean | undefined;
        PDPIsLoaded?: string | undefined;
        ResultURLTrackingEnabled?: string | undefined;
        SearchTaggingReceived?: import("@empathyco/x-types").TaggingRequest | undefined;
        TrackableElementDisplayed?: import("@empathyco/x-types").Taggable | undefined;
        UserClickedPDPAddToCart?: string | undefined;
        TaggingConfigProvided?: import("../../../tagging").TaggingConfig | undefined;
        ExperienceControlsEventsChanged?: Partial<XEventsTypes> | undefined;
        ExperienceControlsRequestUpdated?: import("@empathyco/x-types").ExperienceControlsRequest | null | undefined;
        ParamsLoadedFromUrl?: import("../../../..").UrlParams | undefined;
        ExtraParamsLoadedFromUrl?: Dictionary<unknown> | undefined;
        PushableUrlStateUpdated?: import("../../../..").UrlParams | undefined;
        ReplaceableUrlStateUpdated?: import("../../../..").UrlParams | undefined;
        RelatedPromptsRequestUpdated?: import("@empathyco/x-types").RelatedPromptsRequest | null | undefined;
        SelectedRelatedPromptChanged?: number | undefined;
        UserSelectedARelatedPrompt?: number | undefined;
        UserSelectedARelatedPromptQuery?: number | undefined;
        UserClickedARelatedPromptResult?: import("@empathyco/x-types").Result | undefined;
        UserClickedARelatedPromptAdd2Cart?: import("@empathyco/x-types").Result | undefined;
        RelatedPromptsResponseChanged?: import("@empathyco/x-types").RelatedPrompt[] | undefined;
        RelatedPromptsUnmounted?: void | undefined;
    }>;
    innerCssClasses: import("vue").ComputedRef<(string | Dictionary<boolean>)[]>;
}, unknown, {}, {}, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, {}, string, import("vue").PublicProps, Readonly<import("vue").ExtractPropTypes<{
    /** The filter data to render. */
    filter: {
        type: PropType<SimpleFilterModel>;
        required: true;
    };
    /** Additional events, with their payload, to emit when the filter is clicked. */
    clickEvents: PropType<Partial<XEventsTypes>>;
    /** Inheritance CSS classes. */
    cssClasses: {
        type: PropType<(string | Dictionary<boolean>)[]>;
        default: () => never[];
    };
}>>, {
    cssClasses: (string | Dictionary<boolean>)[];
}, {}>;
export default _default;
//# sourceMappingURL=simple-filter.vue?vue&type=script&lang.d.ts.map