import type { Filter } from '@empathyco/x-types';
import type { PropType } from 'vue';
/**
 * Custom interface to provide a slot name to a Filter.
 *
 * @internal
 */
interface RenderFilter {
    slotName: string;
    selectedFilter: Filter;
}
/**
 * This component renders a list of selected filters from every facet, or from the facet
 * ids passed as property. It uses the SelectedFilters component (state).
 *
 * It provides two slots: a scoped one which name is the filter facet id; and a default one.
 * Both exposes the filter and renders the filter label by default.
 *
 * The property "alwaysVisible" handles if the component is rendered if no filters are selected.
 *
 * @public
 */
declare const _default: import("vue").DefineComponent<{
    /** Array of facets ids used to get the selected filters for those facets. */
    facetsIds: PropType<(string | number)[]>;
    /** Flag to render the component even if there are no filters selected. */
    alwaysVisible: BooleanConstructor;
    /** Animation component that will be used to animate the selected filters list. */
    animation: {
        type: (StringConstructor | ObjectConstructor | FunctionConstructor)[];
        default: string;
    };
}, {
    selectedFilters: import("vue").ComputedRef<Filter[]>;
    mapSlot: (selectedFilters: Filter[]) => RenderFilter[];
    hasSlot: (name: string) => boolean;
}, unknown, {}, {}, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, {}, string, import("vue").PublicProps, Readonly<import("vue").ExtractPropTypes<{
    /** Array of facets ids used to get the selected filters for those facets. */
    facetsIds: PropType<(string | number)[]>;
    /** Flag to render the component even if there are no filters selected. */
    alwaysVisible: BooleanConstructor;
    /** Animation component that will be used to animate the selected filters list. */
    animation: {
        type: (StringConstructor | ObjectConstructor | FunctionConstructor)[];
        default: string;
    };
}>>, {
    alwaysVisible: boolean;
    animation: string | Function | Record<string, any>;
}, {}>;
export default _default;
//# sourceMappingURL=selected-filters-list.vue?vue&type=script&lang.d.ts.map