import type { EditableNumberRangeFilter, Facet, Filter } from '@empathyco/x-types';
import type { Store } from 'vuex';
import type { RootXStoreState } from '../../../store/store.types';
import type { FilterEntity } from './types';
/**
 * Allows selecting and deselecting a filter of {@link @empathyco/x-types#EditableNumberRangeFilter
 * | EditableNumberRangeFilter}.
 *
 * @internal
 */
export declare class EditableNumberRangeFilterEntity implements FilterEntity {
    protected store: Store<RootXStoreState>;
    constructor(store: Store<RootXStoreState>);
    static accepts(filter: Filter): boolean;
    /**
     * It sets {@link @empathyco/x-types#EditableNumberRangeFilter | EditableNumberRangeFilter} to
     * false. Range values are kept to be able to update the {@link FacetsGetters.selectedFilters}
     * getter accordingly (as the id is built using the range).
     *
     * @param filterParam - The filter to deselect.
     */
    deselect(filterParam: Filter): void;
    /**
     * It selects the {@link @empathyco/x-types#EditableNumberRangeFilter
     * | EditableNumberRangeFilter}.
     *
     * @param filterParam - The filter to select.
     * @remarks If the filter has no selected range, then filter is deselected when this
     * method is called.
     */
    select(filterParam: Filter): void;
    /**
     * Generates a new filter id using the range values.
     *
     * @param filter - The filter to generate its new id.
     * @returns The new filter id.
     * @internal
     */
    protected getNewFilterId(filter: Pick<EditableNumberRangeFilter, 'range' | 'facetId'>): string;
    /**
     * It returns if the filter range min or the filter range max is not null.
     *
     * @param filter - The filter to determine if it is selected or not.
     * @returns True if filter range min or filter range max is not null.
     * @internal
     */
    protected isSelected(filter: EditableNumberRangeFilter): boolean;
    /**
     * Removes the previous filter of this facet from the store, only if it exists.
     *
     * @param facetId - The facet to remove its only filter.
     * @internal
     */
    protected removePreviousFilter(facetId: Facet['id']): void;
    /**
     * Retrieves the filter of the given facet id from the store.
     *
     * @param facetId -  The facet id to retrieve its filter.
     * @returns The filter of the facet if it exists.
     * @internal
     */
    protected getFilterByFacet(facetId: Facet['id']): EditableNumberRangeFilter | undefined;
}
//# sourceMappingURL=editable-number-range-filter.entity.d.ts.map