import type { Filter, HierarchicalFilter } from '@empathyco/x-types';
import type { Store } from 'vuex';
import type { RootXStoreState } from '../../../store/store.types';
import type { FilterEntity } from './types';
import { isHierarchicalFilter } from '@empathyco/x-types';
/**
 * Allows selecting and deselecting a filter of {@link @empathyco/x-types#HierarchicalFilter
 * | HierarchicalFilter}.
 *
 * @internal
 */
export declare class HierarchicalFilterEntity implements FilterEntity {
    protected store: Store<RootXStoreState>;
    static accepts: typeof isHierarchicalFilter;
    constructor(store: Store<RootXStoreState>);
    /**
     * Deselects the hierarchical filter and all of its descendants.
     *
     * @param filterParam - The filter to deselect.
     */
    deselect(filterParam: Filter): void;
    /**
     * Selects the hierarchical filter and its ancestors.
     *
     * @param filterParam - The filter to select.
     */
    select(filterParam: Filter): void;
    /**
     * Deselects all the descendants of the given filter, saving them to the store.
     *
     * @remarks The descendants hierarchy is retrieved from the store.
     * @param filter - The filter to deselect its descendants.
     * @internal
     */
    protected deselectDescendants(filter: HierarchicalFilter): void;
    /**
     * Selects all the ancestors of the given filter, saving them to the store.
     *
     * @remarks The ancestors hierarchy is retrieved from the store.
     * @param filter - The filter to select its ancestors.
     * @internal
     */
    protected selectAncestors(filter: HierarchicalFilter): void;
    /**
     * Retrieves a hierarchical filter from the store by its id.
     *
     * @param id - The id of the filter to retrieve.
     * @returns The hierarchical filter retrieved from the store.
     * @internal
     */
    protected getFilterById(id: HierarchicalFilter['id']): HierarchicalFilter;
    /**
     * Saves the given filter to the store.
     *
     * @param filter - The filter to save to the store.
     * @param newFilterState - The new partial state of the filter.
     * @internal
     */
    protected saveFilter(filter: HierarchicalFilter, newFilterState?: Partial<HierarchicalFilter>): void;
}
//# sourceMappingURL=hierarchical-filter.entity.d.ts.map