/**
 * Saves a new query into the history queries.
 *
 * @public
 */
export declare const addQueryToHistoryQueries: import("../..").Wire<string>;
/**
 * Saves the selectedQueryPreview query into the history queries.
 *
 * @public
 */
export declare const addQueryToHistoryQueriesFromPreview: import("../..").AnyWire;
/**
 * Sets the query of the history queries module. Used for searching into the history queries.
 *
 * @public
 */
export declare const setHistoryQueriesQuery: import("../..").Wire<string>;
/**
 * Sets the query of the history queries module from a selectedQueryPreview's query.
 * Used for searching into the history queries.
 *
 * @public
 */
export declare const setHistoryQueriesQueryFromPreview: import("../..").AnyWire;
/**
 * Sets the query of the history queries module to an empty string.
 *
 * @public
 */
export declare const clearHistoryQueriesQuery: import("../..").AnyWire;
/**
 * Triggers a session refresh, extending its validity for the time configured in the
 * {@link HistoryQueriesConfig.sessionTTLInMs}.
 *
 * @public
 */
export declare const refreshHistoryQueriesSession: import("../..").AnyWire;
/**
 * Loads the history queries from the browser storage, saving them to the
 * {@link HistoryQueriesState.historyQueries}.
 *
 * @public
 */
export declare const loadHistoryQueriesFromBrowserStorageWire: import("../..").AnyWire;
/**
 * Clears the history queries.
 *
 * @public
 */
export declare const clearHistoryQueries: import("../..").AnyWire;
/**
 * Removes a single history query from the history queries.
 *
 * @public
 */
export declare const removeHistoryQuery: import("../..").Wire<import("@empathyco/x-types").HistoryQuery>;
/**
 * Enables history queries.
 *
 * @public
 */
export declare const setHistoryQueriesEnabled: import("../..").AnyWire;
/**
 * Disables history queries.
 *
 * @public
 */
export declare const setHistoryQueriesDisabled: import("../..").AnyWire;
/**
 * Updates the history queries with the relevant info included in a search response.
 *
 * @public
 */
export declare const updateHistoryQueriesWithSearchResponse: import("../..").Wire<import("../search").InternalSearchResponse>;
/**
 * Sets the history queries state `filters` with a selectedHistoryQuery's filters.
 *
 * @public
 */
export declare const setSearchSelectedFilters: import("../..").AnyWire;
/**
 * Default wiring for the {@link HistoryQueries} module.
 *
 * @internal
 */
export declare const historyQueriesWiring: {
    ParamsLoadedFromUrl: {
        setUrlParams: import("../..").Wire<import("../..").UrlParams>;
    };
    HistoryQueriesQueryChanged: {
        refreshHistoryQueriesSession: import("../..").AnyWire;
    };
    HistoryQueriesStorageKeyChanged: {
        loadHistoryQueriesFromBrowserStorageWire: import("../..").AnyWire;
    };
    UserClearedQuery: {
        clearHistoryQueriesQuery: import("../..").AnyWire;
    };
    UserAcceptedAQuery: {
        setHistoryQueriesQuery: import("../..").Wire<string>;
        addQueryToHistoryQueries: import("../..").Wire<string>;
    };
    UserSelectedAHistoryQuery: {
        setSearchSelectedFilters: import("../..").AnyWire;
    };
    UserIsTypingAQuery: {
        setHistoryQueriesQueryDebounce: import("../..").Wire<string>;
    };
    UserPressedClearHistoryQueries: {
        clearHistoryQueries: import("../..").AnyWire;
    };
    UserPressedRemoveHistoryQuery: {
        removeHistoryQuery: import("../..").Wire<import("@empathyco/x-types").HistoryQuery>;
    };
    UserClickedEnableHistoryQueries: {
        setHistoryQueriesEnabled: import("../..").AnyWire;
    };
    UserClickedConfirmDisableHistoryQueries: {
        setHistoryQueriesDisabled: import("../..").AnyWire;
    };
    UserClickedCloseX: {
        clearHistoryQueriesQuery: import("../..").AnyWire;
    };
    UserClickedOutOfMainModal: {
        clearHistoryQueriesQuery: import("../..").AnyWire;
    };
    SearchResponseChanged: {
        updateHistoryQueriesWithSearchResponse: import("../..").Wire<import("../search").InternalSearchResponse>;
    };
    UserAcceptedAQueryPreview: {
        setHistoryQueriesQueryFromPreview: import("../..").AnyWire;
        addQueryToHistoryQueriesFromPreview: import("../..").AnyWire;
    };
};
//# sourceMappingURL=wiring.d.ts.map