import type { PropType } from 'vue';
import type { QueryFeature } from '../../../types';
import type { QueryPreviewInfo } from '../store/types';
/**
 * Renders the results previews of a list of objects with the information about the query preview,
 * and exposes the {@link QueryPreview} slots to modify the content.
 * The requests are made in sequential order.
 *
 * @public
 */
declare const _default: import("vue").DefineComponent<{
    /**
     * The list of queries preview to render.
     *
     * @public
     */
    queriesPreviewInfo: {
        type: PropType<QueryPreviewInfo[]>;
        required: true;
    };
    /**
     * The origin property for the request on each query preview.
     *
     * @public
     */
    queryFeature: {
        type: PropType<QueryFeature>;
    };
    /**
     * Number of query preview results to be rendered on each query preview.
     *
     * @public
     */
    maxItemsToRender: {
        type: NumberConstructor;
    };
    /**
     * Debounce time in milliseconds for triggering the search requests
     * on each query preview.
     * It will default to 0 to fit the most common use case (pre-search),
     * and it would work properly with a 250 value inside empathize.
     */
    debounceTimeMs: {
        type: NumberConstructor;
        default: number;
    };
    /**
     * Controls whether all the QueryPreview should be removed from the state
     * when the component is destroyed.
     *
     * @public
     */
    persistInCache: BooleanConstructor;
    /**
     * Animation component that will be used to animate the elements.
     *
     * @public
     */
    animation: {
        type: (StringConstructor | ObjectConstructor | FunctionConstructor)[];
        default: string;
    };
}, {
    renderedQueryPreviews: import("vue").ComputedRef<QueryPreviewInfo[]>;
    flagAsFailed: (failedQuery: string) => void;
    flagAsLoaded: (loadedQuery: string) => void;
}, unknown, {}, {}, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, {}, string, import("vue").PublicProps, Readonly<import("vue").ExtractPropTypes<{
    /**
     * The list of queries preview to render.
     *
     * @public
     */
    queriesPreviewInfo: {
        type: PropType<QueryPreviewInfo[]>;
        required: true;
    };
    /**
     * The origin property for the request on each query preview.
     *
     * @public
     */
    queryFeature: {
        type: PropType<QueryFeature>;
    };
    /**
     * Number of query preview results to be rendered on each query preview.
     *
     * @public
     */
    maxItemsToRender: {
        type: NumberConstructor;
    };
    /**
     * Debounce time in milliseconds for triggering the search requests
     * on each query preview.
     * It will default to 0 to fit the most common use case (pre-search),
     * and it would work properly with a 250 value inside empathize.
     */
    debounceTimeMs: {
        type: NumberConstructor;
        default: number;
    };
    /**
     * Controls whether all the QueryPreview should be removed from the state
     * when the component is destroyed.
     *
     * @public
     */
    persistInCache: BooleanConstructor;
    /**
     * Animation component that will be used to animate the elements.
     *
     * @public
     */
    animation: {
        type: (StringConstructor | ObjectConstructor | FunctionConstructor)[];
        default: string;
    };
}>>, {
    debounceTimeMs: number;
    persistInCache: boolean;
    animation: string | Function | Record<string, any>;
}, {}>;
export default _default;
//# sourceMappingURL=query-preview-list.vue?vue&type=script&lang.d.ts.map