import type { Suggestion } from '@empathyco/x-types';
import type { GettersClass } from '../../../../store/getters.types';
import type { QuerySuggestionsState, QuerySuggestionsXStoreModule } from '../types';
/**
 * Class implementation for the {@link QuerySuggestionsGetter.querySuggestions} getter.
 *
 * @public
 */
export declare class QuerySuggestionsGetter implements GettersClass<QuerySuggestionsXStoreModule> {
    /**
     * Default implementation for the {@link QuerySuggestionsGetter.querySuggestions} getter.
     *
     * @param state - Current {@link https://vuex.vuejs.org/guide/state.html | state} of the query
     * suggestions module.
     * @returns The filtered subset of queries, matching with the current query.
     */
    querySuggestions({ query, suggestions, config, searchedQueries, }: QuerySuggestionsState): Suggestion[];
    /**
     * Creates a function to check in the suggestion queries array the items that match
     * the current query.
     *
     * @param normalizedQuery - The normalized query for search into the array.
     * @returns A filter function for searching into the array of suggestion queries with the provided
     * params.
     * @internal
     */
    protected isInQuerySuggestions(normalizedQuery: string): (suggestion: Suggestion) => boolean;
}
/**
 * Query Suggestions getter.
 *
 * @public
 */
export declare const querySuggestions: ({ query, suggestions, config, searchedQueries, }: QuerySuggestionsState) => Suggestion[];
//# sourceMappingURL=query-suggestions.getter.d.ts.map