import type { PropType } from 'vue';
/**
 * This component shows the list of `RelatedPrompts` components.
 *
 * If the default slot is reimplemented in the consumer, `onSelect` function will be
 * necessary to handle the selection of the related prompt and to trigger the stagger-fade-slide animation.
 *
 * @public
 */
declare const _default: import("vue").DefineComponent<{
    /**
     * The CSS class for the left and right button of the sliding panel.
     *
     * @public
     */
    buttonClass: StringConstructor;
    /**
     * The boolean prop to handle the visiblity of sliding pannel buttons.
     *
     * @public
     */
    showButtons: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * The CSS class for the wrapper of all the related prompt wrapper elements.
     *
     * @public
     */
    scrollContainerClass: StringConstructor;
    /**
     * The CSS class for all the related prompt wrapper elements.
     *
     * @public
     */
    tagClass: StringConstructor;
    /**
     * Array of colors to apply to the related prompts. It will be applied to tag
     * elements cyclically according to their index in the nex way: `tagColors[index % tagColors.length]`.
     *
     * @public
     */
    tagColors: PropType<string[]>;
    /**
     * The duration of the total animation in milliseconds.
     *
     * @public
     */
    animationDurationInMs: {
        type: NumberConstructor;
        default: number;
    };
}, {
    onSelect: (selectedIndex: number) => void;
    onBeforeEnter: (el: Element) => void;
    onEnter: (el: Element, done: () => void) => void;
    onLeave: (el: Element, done: () => void) => void;
    selectedPromptIndex: import("vue").ComputedRef<number>;
    visibleRelatedPrompts: import("vue").ComputedRef<{
        index: number;
        relatedPromptNextQueries?: import("@empathyco/x-types").RelatedPromptNextQuery[] | undefined;
        nextQueries: string[];
        suggestionText: string;
        suggestionImageUrl?: string | undefined;
        type: string;
        toolingDisplayTagging?: import("@empathyco/x-types").TaggingRequest | undefined;
        tagging?: {
            toolingDisplayTagging?: import("@empathyco/x-types").TaggingRequest | undefined;
            toolingDisplayClickTagging?: import("@empathyco/x-types").TaggingRequest | undefined;
            nextQueriesTagging?: import("@empathyco/x-types").RelatedPromptNextQuery[] | undefined;
        } | undefined;
        modelName: "RelatedPrompt";
    }[]>;
    listItems: import("vue").Ref<HTMLElement[]>;
    isAnimating: import("vue").Ref<boolean>;
    x: import("../../../composables").UseAliasAPI & {
        on: <Event_1 extends keyof import("../../..").XEventsTypes, Metadata extends boolean>(event: Event_1, withMetadata: Metadata) => {
            subscribe: (callback: (payload: Metadata extends true ? import("@empathyco/x-bus").SubjectPayload<import("@empathyco/x-bus").EventPayload<import("../../..").XEventsTypes, Event_1>, import("../../..").WireMetadata> : import("@empathyco/x-bus").EventPayload<import("../../..").XEventsTypes, Event_1>) => void) => void;
        };
        emit: <Event_2 extends keyof import("../../..").XEventsTypes>(event: Event_2, payload?: import("../../..").XEventPayload<Event_2> | undefined, metadata?: Omit<import("../../..").WireMetadata, "moduleName">) => Promise<import("@empathyco/x-bus").EmittedData<import("../../..").XEventsTypes, Event_2, import("../../..").WireMetadata>>;
    };
}, unknown, {}, {}, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, {}, string, import("vue").PublicProps, Readonly<import("vue").ExtractPropTypes<{
    /**
     * The CSS class for the left and right button of the sliding panel.
     *
     * @public
     */
    buttonClass: StringConstructor;
    /**
     * The boolean prop to handle the visiblity of sliding pannel buttons.
     *
     * @public
     */
    showButtons: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * The CSS class for the wrapper of all the related prompt wrapper elements.
     *
     * @public
     */
    scrollContainerClass: StringConstructor;
    /**
     * The CSS class for all the related prompt wrapper elements.
     *
     * @public
     */
    tagClass: StringConstructor;
    /**
     * Array of colors to apply to the related prompts. It will be applied to tag
     * elements cyclically according to their index in the nex way: `tagColors[index % tagColors.length]`.
     *
     * @public
     */
    tagColors: PropType<string[]>;
    /**
     * The duration of the total animation in milliseconds.
     *
     * @public
     */
    animationDurationInMs: {
        type: NumberConstructor;
        default: number;
    };
}>>, {
    showButtons: boolean;
    animationDurationInMs: number;
}, {}>;
export default _default;
//# sourceMappingURL=related-prompts-tag-list.vue?vue&type=script&lang.d.ts.map