import type { Redirection as RedirectionModel } from '@empathyco/x-types';
import type { PropType, Ref } from 'vue';
/**
 * A redirection is a component that sends the user to a link in the website. It is helpful when
 * there are queries like `help`, `shipping costs`, `my account`, where a link to a section in the
 * website will be more helpful than the set of results returned.
 *
 * @public
 */
declare const _default: import("vue").DefineComponent<{
    /**
     * The redirection mode. Auto for auto redirection and manual for an user interaction.
     *
     * @public
     */
    mode: {
        type: PropType<"auto" | "manual">;
        default: string;
    };
    /**
     * The waiting time in seconds until the redirection is made.
     *
     * @remarks this delay only works in auto mode.
     *
     * @public
     */
    delayInSeconds: {
        type: NumberConstructor;
        default: number;
    };
}, {
    redirection: import("vue").ComputedRef<RedirectionModel | null>;
    redirect: () => void;
    abortRedirect: () => void;
    isRedirecting: Ref<boolean>;
    slots: Readonly<{
        [name: string]: import("vue").Slot<any> | undefined;
    }>;
}, unknown, {}, {}, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, {}, string, import("vue").PublicProps, Readonly<import("vue").ExtractPropTypes<{
    /**
     * The redirection mode. Auto for auto redirection and manual for an user interaction.
     *
     * @public
     */
    mode: {
        type: PropType<"auto" | "manual">;
        default: string;
    };
    /**
     * The waiting time in seconds until the redirection is made.
     *
     * @remarks this delay only works in auto mode.
     *
     * @public
     */
    delayInSeconds: {
        type: NumberConstructor;
        default: number;
    };
}>>, {
    mode: "auto" | "manual";
    delayInSeconds: number;
}, {}>;
export default _default;
//# sourceMappingURL=redirection.vue?vue&type=script&lang.d.ts.map