import type { InternalSearchRequest } from './types';
/**
 * Cancels the {@link SearchActions.fetchAndSaveSearchResponse} request promise.
 *
 * @public
 */
export declare const cancelFetchAndSaveSearchResponseWire: import("../../wiring").AnyWire;
/**
 * Sets the search state `origin`.
 *
 * @public
 */
export declare const saveOriginWire: import("../../wiring").AnyWire;
/**
 * Requests and stores the search response.
 *
 * @public
 */
export declare const fetchAndSaveSearchResponseWire: import("../../wiring").Wire<InternalSearchRequest | null>;
/**
 * Resets the search state `spellcheckedQuery` to its initial value, an empty string.
 *
 * @public
 */
export declare const resetSpellcheckQuery: import("../../wiring").AnyWire;
/**
 * Sets the search state `relatedTags`.
 *
 * @public
 */
export declare const setRelatedTags: import("../../wiring").Wire<import("@empathyco/x-types").RelatedTag[]>;
/**
 * Sets the search state `query`.
 *
 * @public
 */
export declare const setSearchQuery: import("../../wiring").Wire<string>;
/**
 * Clears the search state `query`.
 *
 * @public
 */
export declare const clearSearchQuery: import("../../wiring").AnyWire;
/**
 * Sets the search state `selectedFilters`.
 *
 * @public
 */
export declare const setSelectedFilters: import("../../wiring").Wire<import("@empathyco/x-types").Filter[]>;
/**
 * Sets the search state `sort`.
 *
 * @public
 */
export declare const setSort: import("../../wiring").Wire<string>;
/**
 * Sets the search state `query`.
 *
 * @public
 */
export declare const setUrlParams: import("../../wiring").Wire<import("../..").UrlParams>;
/**
 * Sets the search state `page`.
 *
 * @public
 */
export declare const setSearchPage: import("../../wiring").Wire<number>;
/**
 * Sets the search state `params`.
 *
 * @public
 */
export declare const setSearchExtraParams: import("../../wiring").Wire<import("@empathyco/x-utils").Dictionary<unknown>>;
/**
 * Resets the search state to reload the current search.
 *
 * @public
 */
export declare const resetStateForReloadWire: import("../../wiring").AnyWire;
/**
 * Resets the search state `isNoResults`.
 *
 * @public
 */
export declare const resetIsNoResults: import("../../wiring").AnyWire;
/**
 * Resets the search state `fromNoResultsWithFilters`.
 *
 * @public
 */
export declare const resetFromNoResultsWithFilters: import("../../wiring").AnyWire;
/**
 * Increases the current search state `page` by one.
 *
 * @public
 */
export declare const increasePageAppendingResultsWire: import("../../wiring").AnyWire;
/**
 * Resets the search state `isAppendingResults`.
 *
 * @public
 */
export declare const resetAppending: import("../../wiring").AnyWire;
/**
 * Resets the {@link SearchGetters.request} parameters when refining request and before the actual
 * request is launched.
 *
 * @public
 */
export declare const resetRequestOnRefinementWire: import("../../wiring").AnyWire;
/**
 * Resets the search state when the request is changed to null. See the
 * {@link SearchXStoreModule} for details.
 *
 * @public
 */
export declare const resetStateIfNoRequestWire: import("../../wiring").Wire<InternalSearchRequest | null>;
/**
 * Sets the search state `query` with the selectedQueryPreview's query.
 *
 * @public
 */
export declare const setSearchQueryFromPreview: import("../../wiring").AnyWire;
/**
 * Sets the search state `params` with the selectedQueryPreview's extraParams.
 *
 * @public
 */
export declare const setSearchExtraParamsFromPreview: import("../../wiring").AnyWire;
/**
 * Sets the search state `selectedFilters` with the selectedQueryPreview's filters.
 *
 * @public
 */
export declare const setSearchSelectedFiltersFromPreview: import("../../wiring").AnyWire;
/**
 * Sets the search state `selectedFilters` with a selectedHistoryQuery's filters.
 *
 * @public
 */
export declare const setSearchSelectedFiltersFromHistoryQuery: import("../../wiring").AnyWire;
/**
 * Search wiring.
 *
 * @internal
 */
export declare const searchWiring: {
    ParamsLoadedFromUrl: {
        setUrlParams: import("../../wiring").Wire<import("../..").UrlParams>;
        saveOriginWire: import("../../wiring").AnyWire;
    };
    UserAcceptedAQuery: {
        setSearchQuery: import("../../wiring").Wire<string>;
        saveOriginWire: import("../../wiring").AnyWire;
    };
    UserAcceptedSpellcheckQuery: {
        resetSpellcheckQuery: import("../../wiring").AnyWire;
    };
    UserClearedQuery: {
        setSearchQuery: import("../../wiring").Wire<string>;
        cancelFetchAndSaveSearchResponseWire: import("../../wiring").AnyWire;
        resetFromNoResultsWithFilters: import("../../wiring").AnyWire;
        resetIsNoResults: import("../../wiring").AnyWire;
    };
    UserClickedASort: {
        setSort: import("../../wiring").Wire<string>;
    };
    UserPickedARelatedTag: {
        saveOriginWire: import("../../wiring").AnyWire;
    };
    UserReachedResultsListEnd: {
        increasePageAppendingResultsWire: import("../../wiring").AnyWire;
    };
    SearchRequestUpdated: {
        resetStateIfNoRequestWire: import("../../wiring").Wire<InternalSearchRequest | null>;
        fetchAndSaveSearchResponseWire: import("../../wiring").Wire<InternalSearchRequest | null>;
    };
    SearchRequestChanged: {
        resetRequestOnRefinementWire: import("../../wiring").AnyWire;
    };
    SelectedRelatedTagsChanged: {
        setRelatedTags: import("../../wiring").Wire<import("@empathyco/x-types").RelatedTag[]>;
    };
    SelectedFiltersForRequestChanged: {
        setSelectedFilters: import("../../wiring").Wire<import("@empathyco/x-types").Filter[]>;
    };
    ResultsChanged: {
        resetAppending: import("../../wiring").AnyWire;
    };
    ReloadSearchRequested: {
        resetStateForReloadWire: import("../../wiring").AnyWire;
    };
    SelectedSortProvided: {
        setSort: import("../../wiring").Wire<string>;
    };
    ExtraParamsChanged: {
        setSearchExtraParams: import("../../wiring").Wire<import("@empathyco/x-utils").Dictionary<unknown>>;
    };
    UserClickedCloseX: {
        clearSearchQuery: import("../../wiring").AnyWire;
    };
    UserClickedOutOfMainModal: {
        clearSearchQuery: import("../../wiring").AnyWire;
    };
    UserAcceptedAQueryPreview: {
        setSearchQueryFromPreview: import("../../wiring").AnyWire;
        setSearchExtraParamsFromPreview: import("../../wiring").AnyWire;
        setSearchSelectedFiltersFromPreview: import("../../wiring").AnyWire;
        saveOriginWire: import("../../wiring").AnyWire;
    };
    QueryPreviewUnselected: {
        setSearchExtraParams: import("../../wiring").Wire<import("@empathyco/x-utils").Dictionary<unknown>>;
    };
    UserSelectedAHistoryQuery: {
        setSearchSelectedFiltersFromHistoryQuery: import("../../wiring").AnyWire;
    };
    UserSelectedAPage: {
        setSearchPage: import("../../wiring").Wire<number>;
        resetAppending: import("../../wiring").AnyWire;
    };
};
//# sourceMappingURL=wiring.d.ts.map