import type { Result, Taggable, Tagging, TaggingRequest } from '@empathyco/x-types';
import type { Wire } from '../../wiring/wiring.types';
/**
 * Sets the tagging state `consent`.
 *
 * @public
 */
export declare const setConsent: Wire<boolean>;
/**
 * Sets the tagging state `noResultsTaggingEnabled`.
 *
 * @public
 */
export declare const setNoResultsTaggingEnabledWire: Wire<keyof import("../x-modules.types").XModulesTree>;
/**
 * Sets the tagging config state.
 *
 * @public
 */
export declare const setTaggingConfig: Wire<import("./config.types").TaggingConfig>;
/**
 * Tracks the tagging of the query.
 *
 * @public
 */
export declare const trackQueryWire: Wire<TaggingRequest | TaggingRequest[]>;
/**
 * Sets the tagging state of the query tagging info using a debounce which ends if the user
 * accepts a query.
 *
 * @public
 */
export declare const setQueryTaggingInfo: Wire<TaggingRequest>;
/**
 * Sets the tagging state of the query tagging info using.
 *
 * @public
 */
export declare const setQueryTaggingFromQueryPreview: Wire<Taggable>;
/**
 * Tracks the tagging of the result.
 *
 * @public
 */
export declare const trackResultClickedWire: Wire<Taggable>;
/**
 * Tracks the tagging of the banner.
 *
 * @public
 */
export declare const trackBannerClickedWire: Wire<Taggable>;
/**
 * Tracks the click on a promoted result.
 *
 * @public
 */
export declare const trackPromotedClickedWire: Wire<Taggable>;
/**
 * Performs a track of a result added to the cart.
 *
 * @public
 */
export declare const trackAddToCartWire: Wire<Taggable>;
/**
 * Performs a track of a display result being clicked.
 *
 * @public
 */
export declare const trackDisplayClickedWire: Wire<Taggable>;
/**
 * Performs a track of a display result being clicked.
 *
 * @public
 */
export declare const trackToolingDisplayClickedWire: Wire<Taggable>;
/**
 * Performs a track of a display result being clicked.
 *
 * @public
 */
export declare const trackToolingAdd2CartWire: Wire<Taggable>;
/**
 * Performs a track of a clicked related prompt.
 *
 * @public
 */
export declare const trackRelatedPromptToolingDisplayClickWire: Wire<any>;
/**
 * Performs a track of a display element appearing.
 *
 * @public
 */
export declare const trackElementDisplayedWire: Wire<Taggable>;
/**
 * Factory helper to create a wire for the track of a taggable element.
 *
 * @param property - Key of the tagging object to track.
 * @returns A new wire for the given property of the taggable element.
 *
 * @public
 */
export declare function createTrackWire(property: keyof Tagging): Wire<Taggable>;
/**
 * Performs a track of a query with no results that used related prompts or semantic queries as fallback.
 * The totalHits will be changed to -1 if related prompts or semantic queries are found in order to differentiate
 * it from scenarios where the user encounters a no-results page without any related prompts or semantic queries.
 *
 * @public
 */
export declare const trackNoResultsQueryWithFallbackWire: Wire<any>;
/**.
 * Debounced version of {@link trackNoResultsQueryWithFallbackWire}
 *
 * @public
 */
export declare const trackNoResultsQueryWithFallbackWireDebounced: Wire<any>;
/**
 * Performs a track of a query with no results that used semantic queries as fallback.
 * The totalHits will be changed to -1 if semantic queries are found in order to differentiate
 * it from scenarios where the user encounters a no-results page without any semantic queries.
 *
 * @public
 * @deprecated - Use {@link trackNoResultsQueryWithFallbackWire} instead.
 */
export declare const trackNoResultsQueryWithSemanticsWire: Wire<any>;
/**
 * Debounced version of {@link trackNoResultsQueryWithFallbackWire}
 *
 * @public
 * @deprecated - Use {@link trackNoResultsQueryWithFallbackWireDebounced} instead.
 */
export declare const trackNoResultsQueryWithSemanticsWireDebounced: Wire<any>;
/**
 * Factory helper to create a wire for the track of the display click.
 *
 * @param property - Key of the tagging object to track.
 * @returns A new wire for the display click of the taggable element.
 *
 * @public
 */
export declare function createTrackDisplayWire(property: keyof Tagging): Wire<Taggable>;
/**
 * Factory helper to create a wire for the track of the tooling display click.
 *
 * @returns A new wire for the tooling display click of the taggable element.
 *
 * @public
 */
export declare function createTrackToolingDisplayWire(): Wire<Taggable>;
/**
 * Factory helper to create a wire for the track of the tooling display add to cart.
 *
 * @returns A new wire for the tooling display add to cart of the taggable element.
 *
 * @public
 */
export declare function createTrackToolingAdd2CartWire(): Wire<Taggable>;
/**
 * Factory helper to create a wire for the track of the tooling display click in a related prompt.
 *
 * @returns A new wire for the tooling display click of the taggable element.
 *
 * @public
 */
export declare function createTrackRelatedPromptToolingDisplayClickWire(): Wire<any>;
/**
 * Factory helper to create a wire to set the queryTagging.
 *
 * @returns A new wire for the query of a result of a queryPreview.
 *
 * @public
 */
export declare function createSetQueryTaggingFromQueryPreview(): Wire<Taggable>;
/**
 * Wiring configuration for the {@link TaggingXModule | tagging module}.
 *
 * @internal
 */
export declare const taggingWiring: {
    ConsentProvided: {
        setConsent: Wire<boolean>;
    };
    ConsentChanged: {
        clearSessionWire: Wire<any>;
    };
    PDPIsLoaded: {
        moveClickedResultToSessionWire: Wire<string>;
    };
    ResultURLTrackingEnabled: {
        moveClickedResultToSessionWire: Wire<string>;
    };
    SearchTaggingChanged: {
        setQueryTaggingInfo: Wire<TaggingRequest>;
    };
    SearchTaggingReceived: {
        trackQueryWire: Wire<TaggingRequest | TaggingRequest[]>;
    };
    TrackableElementDisplayed: {
        trackElementDisplayedWire: Wire<Taggable>;
    };
    TaggingConfigProvided: {
        setTaggingConfig: Wire<import("./config.types").TaggingConfig>;
    };
    UserClickedAResult: {
        trackResultClickedWire: Wire<Taggable>;
        storeClickedResultWire: Wire<Result>;
    };
    UserClickedResultAddToCart: {
        trackAddToCartWire: Wire<Taggable>;
        trackResultClickedWire: Wire<Taggable>;
        storeAddToCartWire: Wire<Result>;
    };
    UserClickedPDPAddToCart: {
        trackAddToCartFromSessionStorage: Wire<string | undefined>;
    };
    UserClickedABanner: {
        trackBannerClickedWire: Wire<Taggable>;
    };
    UserClickedAPromoted: {
        trackPromotedClickedWire: Wire<Taggable>;
    };
    UserClickedADisplayResult: {
        trackDisplayClickedWire: Wire<Taggable>;
        setQueryTaggingFromQueryPreview: Wire<Taggable>;
    };
    SemanticQueriesResponseChanged: {
        trackNoResultsQueryWithFallbackWireDebounced: Wire<any>;
    };
    RelatedPromptsResponseChanged: {
        trackNoResultsQueryWithFallbackWireDebounced: Wire<any>;
    };
    ModuleRegistered: {
        setNoResultsTaggingEnabledWire: Wire<keyof import("../x-modules.types").XModulesTree>;
    };
    UserClickedARelatedPromptResult: {
        trackToolingDisplayClickedWire: Wire<Taggable>;
    };
    UserClickedARelatedPromptAdd2Cart: {
        trackToolingAdd2CartWire: Wire<Taggable>;
    };
    UserSelectedARelatedPrompt: {
        trackRelatedPromptToolingDisplayClickWire: Wire<any>;
    };
};
//# sourceMappingURL=wiring.d.ts.map