import type { UrlParams } from '../../../types/url-params';
import type { UrlParamKey } from './types';
/**
 * The params from {@link UrlParams} that provokes a replace instead of a push in the browser URL
 * state.
 *
 * @internal
 */
export declare const replaceableParams: UrlParamKey[];
/**
 * Compares new and old {@link UrlParams} to know if not replaceable params have changed.
 *
 * @param newParams - The new {@link UrlParams} to compare.
 * @param oldParams - The old {@link UrlParams} to compare.
 *
 * @returns True if is pushable change, false otherwise.
 */
declare function shouldPushUrl(newParams?: Partial<UrlParams>, oldParams?: Partial<UrlParams>): boolean;
/**
 * Compares new and old {@link UrlParams} to know if replaceable params have changed.
 *
 * @param newParams - The new {@link UrlParams} to compare.
 * @param oldParams - The old {@link UrlParams} to compare.
 *
 * @returns True if is pushable change, false otherwise.
 */
declare function shouldReplaceUrl(newParams?: Partial<UrlParams>, oldParams?: Partial<UrlParams>): boolean;
/**
 * {@link StoreEmitters} For the URL module.
 *
 * @internal
 */
export declare const urlEmitters: {
    PushableUrlStateUpdated: {
        selector: (_: import("./types").UrlState, getters: import("../../..").Returns<import("../../../store").GettersTree<import("./types").UrlState, import("./types").UrlGetters>>) => UrlParams;
        filter: typeof shouldPushUrl;
        metadata: {
            replaceable: false;
        };
    };
    ReplaceableUrlStateUpdated: {
        selector: (_: import("./types").UrlState, getters: import("../../..").Returns<import("../../../store").GettersTree<import("./types").UrlState, import("./types").UrlGetters>>) => UrlParams;
        filter: typeof shouldReplaceUrl;
        metadata: {
            replaceable: false;
        };
    };
};
export {};
//# sourceMappingURL=emitters.d.ts.map